@@ -5,6 +5,6 @@ void Arg::fillLongOptions(OptStruct *optStruct,
                             LongOption const * const begin,
                             LongOption const * const end)
 {
-    for (LongOption const *it = begin; it != end; it++, optStruct++)
+    for (LongOption const *it = begin; it != end; ++it, ++optStruct)
         addLongOption(optStruct, optString, *it);
 }
