@@ -1,6 +1,6 @@
 #include "argconfig.ih"
 
-ArgConfig::const_RE_iterator ArgConfig::findLongOption(int optChar) const
+ArgConfig::const_RE_iterator ArgConfig::findLongOption(int optChar)
 {
     map<int, string>::const_iterator optIt = d_longOption.find(optChar);
 
