@@ -31,7 +31,7 @@ void CGI::setFileDestination(std::string const &path,
     if (!destPath.isType(Stat::DIRECTORY))
         throw Errno(1, "FBB::CGI: can't create file destination "
                                                             "directory ") <<
-                insertable << destPath.path() << throwable;
+                       destPath.path();
 
     d_filePrefix = prefix;
 }
