@@ -4,9 +4,7 @@
 //                   trimmed text following key. initial ws before
 //                   key should not be specified: skipped by findKeyTail.
 
-string ConfigFile::findKeyTail(string const &key, size_t idx) const
+string ConfigFile::findKeyTail(string const &keyPattern, size_t count)
 {
-    static Pattern pattern("^\\s*\\S+\\s+(.*)\\s*$");  // pick 2nd term as [1]
-
-    return searchFor(key, pattern, idx);
+    return searchFor("^\\s*" + keyPattern + "\\s+(.*)\\s*$", count);
 }
