@@ -5,8 +5,8 @@ ReadLineBuf::ReadLineBuf(string const &prompt, size_t historySize, Type type)
     d_history(historySize > 0),
     d_prompt(prompt),
     d_buffer(0),
-    d_timestamp(0),
-    d_readline(&ReadLineBuf::readLine)
+    d_readline(&ReadLineBuf::readLine),
+    d_timestamp(0)
 {
     if (!d_history)
     {
